
;----------
; This is the "Multi-generation Two-strategy Proximity Model" described
; in "Symmetry-Based Reciprocity: Evolutionary Constraints on a
; Proximate Mechanism", by Marco Campennì and Gabriele Schino.
; This model implements an evolutionary (multi-generation)
; version of symmetry based reciprocity based on interindividual
; proximity. Agents adopt one of two strategies: choosing cooperation
; and selfish.
;----------

turtles-own [
  id 
  behavior 
  fitness
]

patches-own []

globals [
  vision 
  time
  rate 
  reproduction 
  mutation_rate 
  time_steps 
  coop_cost
  altruist_percentage
  only-receiving_percentage
  only-giving_percentage
  mean_fitness
  max_fitness
  cont
]

;----------
; creating agents and setting up global variables
;----------
to setup
  __clear-all-and-reset-ticks
  create-agents individuals
  set time 50000
  set reproduction 0.20
  set rate individuals * reproduction
  ifelse mutation = true [set mutation_rate 0.1] [set mutation_rate 0]
  set time_steps 1000
  set coop_cost 1
  set mean_fitness 0
  set max_fitness 0
  set cont 0
end

;----------
; creating agents and setting up all their properties
;----------
to create-agents [x]
  crt x
  ask turtles [
    set color blue
    set shape "circle"
    set id who
    set size 1
    set fitness 0
    set behavior 0
    setxy precision random-xcor 3 precision random-ycor 3
  ]
  
  if experimental_condition = "choosing_altruists-selfish_090-010" [
    set altruist_percentage 0.90
    set only-receiving_percentage 0.10
    ask n-of (individuals * altruist_percentage) turtles with [behavior = 0] [set behavior 1]
    ask n-of (individuals * only-receiving_percentage) turtles with [behavior = 0] [set behavior 3]
    if any? turtles with [behavior = 0] [
      display show "wrong number of agents with right behavior"
      stop
    ]
  ]
  if experimental_condition = "choosing_altruists-selfish_050-050" [
    set altruist_percentage 0.50
    set only-receiving_percentage 0.50
    ask n-of (individuals * altruist_percentage) turtles with [behavior = 0] [set behavior 1]
    ask n-of (individuals * only-receiving_percentage) turtles with [behavior = 0] [set behavior 3]
    if any? turtles with [behavior = 0] [
      display show "wrong number of agents with right behavior"
      stop
    ]
  ]
  if experimental_condition = "choosing_altruists-selfish_010-090" [
    set altruist_percentage 0.10
    set only-receiving_percentage 0.90
    ask n-of (individuals * altruist_percentage) turtles with [behavior = 0] [set behavior 1]
    ask n-of (individuals * only-receiving_percentage) turtles with [behavior = 0] [set behavior 3]
    if any? turtles with [behavior = 0] [
      display show "wrong number of agents with right behavior"
      stop
    ]
  ]
end

;----------
; managing the interactions between agents
;----------
to interact
  
  ;----------
  ; finding n (-> candidates-for-interaction) other agents
  ;----------
  let other_turtles turtles with [self != myself]
  let recipient_candidates n-of candidates-for-interaction other_turtles
  
  ;----------
  ; the decision takes place
  ;----------
  if behavior = 1 [
    let winner min-one-of recipient_candidates [distance myself]
    if [behavior] of winner = 1 or [behavior] of winner = 3 [
      ask self [set fitness fitness - coop_cost]
      ask winner [set fitness fitness + coop_ben]
    ]
  ]
  
end


;----------
; a very simple evolutionary algorithm
;----------
to reproduce
  let chance random-float 1
  
  let best_individuals max-n-of rate turtles [fitness]
  ask best_individuals [
    hatch 1 [
      set id who
      if chance < mutation_rate [
        if experimental_condition = "choosing_altruists-selfish_090-010" [set behavior (4 / ((random 2) + 1)) - 1]
        if experimental_condition = "choosing_altruists-selfish_050-050" [set behavior (4 / ((random 2) + 1)) - 1]
        if experimental_condition = "choosing_altruists-selfish_010-090" [set behavior (4 / ((random 2) + 1)) - 1]
      ]
    ]
  ]
  
  let worst_individuals min-n-of rate turtles [fitness]
  ask worst_individuals [die]
end

to move
  set heading random-float 360
  fd 1
end

;----------
; the engine of the simulation
;----------
to go
  
  if write-on = "file" [
    file-open (word "spatial-tag_fixed-strategies" "exp" experimental_condition ".csv")
  ]
  
  ask turtles [
    move
    interact
  ]
  
  tick
  
  if remainder ticks time_steps = 0 [
    reproduce
    plot_fitness
    set mean_fitness mean [fitness] of turtles
    set max_fitness max [fitness] of turtles
    
    set cont cont + 1
    
    if write-on = "file" [
      
      file-write experimental_condition
      file-write mutation
      file-write count turtles with [behavior = 1] / individuals
      file-write count turtles with [behavior = 3] / individuals
      file-write mean_fitness
      file-write max_fitness
      file-write coop_ben
      file-write candidates-for-interaction
      file-write runs
      file-write cont
      file-print " "
      file-close-all
    ]
    
    ask turtles [
      set fitness 0
      setxy precision random-xcor 3 precision random-ycor 3
    ]
    
  ]
  
  plot_results
  
  
  if ticks = time [
    if write-on = "neither" [
      file-close-all
      stop
    ]
    file-close-all
    stop]
  
  if any? turtles with [behavior = 0] [
    display show "error !!!"
    stop]
  
end

to plot_fitness
  set-current-plot "fitness"
  set-current-plot-pen "mean_fit"
  plot mean [fitness] of turtles 
  set-current-plot-pen "max_fit"
  plot max [fitness] of turtles
end


to plot_results
  set-current-plot "evolution"
  set-current-plot-pen "pop1"
  plot count turtles with [behavior = 1]
  set-current-plot-pen "pop2"
  plot count turtles with [behavior = 2]
  set-current-plot-pen "pop3"
  plot count turtles with [behavior = 3]
end
@#$#@#$#@
GRAPHICS-WINDOW
12
10
426
445
50
50
4.0
1
10
1
1
1
0
1
1
1
-50
50
-50
50
0
0
1
ticks
30.0

BUTTON
532
10
598
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
534
62
597
95
run
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
657
11
829
44
individuals
individuals
10
100
50
10
1
NIL
HORIZONTAL

SLIDER
658
59
830
92
memory-size
memory-size
0
10000
100
1
1
NIL
HORIZONTAL

CHOOSER
731
112
831
157
write-on
write-on
"file" "output_area" "neither"
2

SLIDER
535
153
707
186
runs
runs
0
100
30
1
1
NIL
HORIZONTAL

PLOT
442
241
642
391
evolution
NIL
NIL
0.0
10.0
0.0
100.0
true
false
"" ""
PENS
"pop0" 1.0 0 -2674135 true "" ""
"pop1" 1.0 0 -7500403 true "" ""
"pop2" 1.0 0 -10899396 true "" ""
"pop3" 1.0 0 -16777216 true "" ""

PLOT
656
243
856
393
fitness
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"max_fit" 1.0 0 -16777216 true "" ""
"mean_fit" 1.0 2 -955883 true "" ""

CHOOSER
493
414
861
459
experimental_condition
experimental_condition
"choosing_altruists-selfish_090-010" "choosing_altruists-selfish_050-050" "choosing_altruists-selfish_010-090"
1

SWITCH
742
470
854
503
mutation
mutation
0
1
-1000

SLIDER
535
117
707
150
coop_ben
coop_ben
0
100
50
0.1
1
NIL
HORIZONTAL

SLIDER
536
194
713
227
candidates-for-interaction
candidates-for-interaction
2
individuals - 1
2
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This section could give a general understanding of what the model is trying to show or explain.

## HOW IT WORKS

This section could explain what rules the agents use to create the overall behavior of the model.

## HOW TO USE IT

This section could explain how to use the model, including a description of each of the items in the interface tab.

## THINGS TO NOTICE

This section could give some ideas of things for the user to notice while running the model.

## THINGS TO TRY

This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.

## EXTENDING THE MODEL

This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.

## CREDITS AND REFERENCES

This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="evolution-choosing_altruists-selfish_045-005-vary_candidates" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="memory-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="individuals">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-on">
      <value value="&quot;file&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="runs" first="1" step="1" last="30"/>
    <enumeratedValueSet variable="mutation">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimental_condition">
      <value value="&quot;choosing_altruists-selfish_090-010&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_cost">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_ben">
      <value value="1.1"/>
      <value value="2"/>
      <value value="5"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="candidates-for-interaction">
      <value value="2"/>
      <value value="10"/>
      <value value="25"/>
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="evolution-choosing_altruists-selfish_025-025-vary_candidates" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles with [behavior = 1] / individuals</metric>
    <metric>count turtles with [behavior = 3] / individuals</metric>
    <metric>mean_fitness</metric>
    <metric>max_fitness</metric>
    <enumeratedValueSet variable="memory-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="individuals">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-on">
      <value value="&quot;file&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="runs" first="1" step="1" last="30"/>
    <enumeratedValueSet variable="mutation">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimental_condition">
      <value value="&quot;choosing_altruists-selfish_050-050&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_cost">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_ben">
      <value value="1.1"/>
      <value value="2"/>
      <value value="5"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="candidates-for-interaction">
      <value value="2"/>
      <value value="10"/>
      <value value="25"/>
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="evolution-choosing_altruists-selfish_005-045-vary_candidates" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="memory-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="individuals">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-on">
      <value value="&quot;file&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="runs" first="1" step="1" last="30"/>
    <enumeratedValueSet variable="mutation">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimental_condition">
      <value value="&quot;choosing_altruists-selfish_010-090&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_cost">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_ben">
      <value value="1.1"/>
      <value value="2"/>
      <value value="5"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="candidates-for-interaction">
      <value value="2"/>
      <value value="10"/>
      <value value="25"/>
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="evolution-choosing_altruists-selfish_025-025-vary_candidates_STEPS_ROBUSTNESS" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="memory-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="individuals">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-on">
      <value value="&quot;file&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="runs" first="1" step="1" last="30"/>
    <enumeratedValueSet variable="mutation">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimental_condition">
      <value value="&quot;choosing_altruists-selfish_010-090&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_cost">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_ben">
      <value value="1.1"/>
      <value value="2"/>
      <value value="5"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="candidates-for-interaction">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="evolution-all3exp-vary_candidates_mutation" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <enumeratedValueSet variable="memory-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="individuals">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="write-on">
      <value value="&quot;file&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="runs" first="1" step="1" last="30"/>
    <enumeratedValueSet variable="mutation">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="experimental_condition">
      <value value="&quot;choosing_altruists-selfish_090-010&quot;"/>
      <value value="&quot;choosing_altruists-selfish_050-050&quot;"/>
      <value value="&quot;choosing_altruists-selfish_010-090&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_cost">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groom_ben">
      <value value="1.1"/>
      <value value="2"/>
      <value value="5"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="candidates-for-interaction">
      <value value="2"/>
      <value value="10"/>
      <value value="25"/>
      <value value="49"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
